# Changelog

## v0.1.0

- Add [documentation](https://cirss.github.io/geist-p)
- Add the component tag to extract connected components of a given graph
- Add the process_str_for_html filter
- Make the map tag more flexible: make it possible to map selected columns
- Fix the quotes bug: keep the cell's original format

## v0.0.1

- The first version of GEIST with create, load, query, destroy, graph, graph2, map, use, html, img, and table tags
- SPARQL queries are supported by GEIST based on [RDFLib](https://github.com/RDFLib/rdflib)
